==> igniteui-angular-charts-14.1.1.tgz: package/esm5/lib/PolarScatterSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { PolarBase } from "./PolarBase";
import { markType } from "igniteui-angular-core";
import { PolarBaseView } from "./PolarBaseView";
import { Defaults } from "./Defaults";
import { Color } from "igniteui-angular-core";
/**
 * @hidden
 */
var PolarScatterSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PolarScatterSeries, _super);
    function PolarScatterSeries() {
        var _this = _super.call(this) || this;
        _this.ab = PolarScatterSeries.$;
        return _this;
    }
    PolarScatterSeries.prototype.get_c4 = function () {
        return true;
    };
    PolarScatterSeries.prototype.bx = function () {
        return new PolarScatterSeriesView(this);
    };
    PolarScatterSeries.prototype.lz = function (a) {
        _super.prototype.lz.call(this, a);
        this.u2 = a;
    };
    PolarScatterSeries.prototype.gv = function () {
        return 0.7;
    };
    PolarScatterSeries.prototype.p7 = function () {
        if (this.p6 == 0) {
            return 2;
        }
        return _super.prototype.p7.call(this);
    };
    PolarScatterSeries.$t = markType(PolarScatterSeries, 'PolarScatterSeries', PolarBase.$);
    return PolarScatterSeries;
}(PolarBase));
export { PolarScatterSeries };
/**
 * @hidden
 */
var PolarScatterSeriesView = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PolarScatterSeriesView, _super);
    function PolarScatterSeriesView(a) {
        var _this = _super.call(this, a) || this;
        _this.c3 = null;
        _this.c3 = a;
        return _this;
    }
    PolarScatterSeriesView.prototype.as = function () {
        _super.prototype.as.call(this);
        if (!this.q) {
            this.c3.qd = Defaults.e;
        }
    };
    PolarScatterSeriesView.prototype.af = function () {
        var a = new Color();
        a.colorString = "rgba(95,95,95,0.5)";
        this.e.pb = a;
        this.e.gw = 3;
        this.e.gx = 2;
        this.e.gy = 2;
        this.e.e7 = false;
    };
    PolarScatterSeriesView.$t = markType(PolarScatterSeriesView, 'PolarScatterSeriesView', PolarBaseView.$);
    return PolarScatterSeriesView;
}(PolarBaseView));
export { PolarScatterSeriesView };

==> igniteui-angular-charts-16.0.0.tgz: package/esm5/lib/PolarScatterSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { PolarBase } from "./PolarBase";
import { markType } from "igniteui-angular-core";
import { PolarBaseView } from "./PolarBaseView";
import { Defaults } from "./Defaults";
import { Color } from "igniteui-angular-core";
/**
 * @hidden
 */
var PolarScatterSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PolarScatterSeries, _super);
    function PolarScatterSeries() {
        var _this = _super.call(this) || this;
        _this.ab = PolarScatterSeries.$;
        return _this;
    }
    PolarScatterSeries.prototype.get_c4 = function () {
        return true;
    };
    PolarScatterSeries.prototype.bx = function () {
        return new PolarScatterSeriesView(this);
    };
    PolarScatterSeries.prototype.l2 = function (a) {
        _super.prototype.l2.call(this, a);
        this.u6 = a;
    };
    PolarScatterSeries.prototype.gx = function () {
        return 0.7;
    };
    PolarScatterSeries.prototype.qb = function () {
        if (this.qa == 0) {
            return 2;
        }
        return _super.prototype.qb.call(this);
    };
    PolarScatterSeries.$t = markType(PolarScatterSeries, 'PolarScatterSeries', PolarBase.$);
    return PolarScatterSeries;
}(PolarBase));
export { PolarScatterSeries };
/**
 * @hidden
 */
var PolarScatterSeriesView = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PolarScatterSeriesView, _super);
    function PolarScatterSeriesView(a) {
        var _this = _super.call(this, a) || this;
        _this.c3 = null;
        _this.c3 = a;
        return _this;
    }
    PolarScatterSeriesView.prototype.as = function () {
        _super.prototype.as.call(this);
        if (!this.q) {
            this.c3.qh = Defaults.e;
        }
    };
    PolarScatterSeriesView.prototype.af = function () {
        var a = new Color();
        a.colorString = "rgba(95,95,95,0.5)";
        this.e.pf = a;
        this.e.gy = 3;
        this.e.gz = 2;
        this.e.g0 = 2;
        this.e.e9 = false;
    };
    PolarScatterSeriesView.$t = markType(PolarScatterSeriesView, 'PolarScatterSeriesView', PolarBaseView.$);
    return PolarScatterSeriesView;
}(PolarBaseView));
export { PolarScatterSeriesView };
